git.delta.rocks / unique-network / refs/commits / 6afd9fe97b2d

difftreelog

misk: update stubs

Trubnikov Sergey2022-10-25parent: #846b910.patch.diff
in: master

7 files changed

modifiedpallets/nonfungible/src/stubs/UniqueNFT.soldiffbeforeafterboth
--- a/pallets/nonfungible/src/stubs/UniqueNFT.sol
+++ b/pallets/nonfungible/src/stubs/UniqueNFT.sol
@@ -106,6 +106,7 @@
 /// @title A contract that allows you to work with collections.
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0xb3152af3
 =======
 /// @dev the ERC-165 identifier for this interface is 0x674be726
@@ -113,6 +114,9 @@
 =======
 /// @dev the ERC-165 identifier for this interface is 0x943ee094
 >>>>>>> fix: after rebase
+=======
+/// @dev the ERC-165 identifier for this interface is 0xefe988e0
+>>>>>>> misk: update stubs
 contract Collection is Dummy, ERC165 {
 	/// Set collection property.
 	///
@@ -130,7 +134,7 @@
 	/// Set collection properties.
 	///
 	/// @param properties Vector of properties key/value pair.
-	/// @dev EVM selector for this function is: 0xf90c1ce9,
+	/// @dev EVM selector for this function is: 0x50b26b2a,
 	///  or in textual repr: setCollectionProperties((string,bytes)[])
 	function setCollectionProperties(Tuple21[] memory properties) public {
 		require(false, stub_error);
@@ -152,7 +156,7 @@
 	/// Delete collection properties.
 	///
 	/// @param keys Properties keys.
-	/// @dev EVM selector for this function is: 0x56d4684a,
+	/// @dev EVM selector for this function is: 0xee206ee3,
 	///  or in textual repr: deleteCollectionProperties(string[])
 	function deleteCollectionProperties(string[] memory keys) public {
 		require(false, stub_error);
@@ -179,7 +183,7 @@
 	///
 	/// @param keys Properties keys. Empty keys for all propertyes.
 	/// @return Vector of properties key/value pairs.
-	/// @dev EVM selector for this function is: 0x5cad7311,
+	/// @dev EVM selector for this function is: 0x285fb8e6,
 	///  or in textual repr: collectionProperties(string[])
 	function collectionProperties(string[] memory keys) public view returns (Tuple21[] memory) {
 		require(false, stub_error);
@@ -206,9 +210,16 @@
 	/// @dev In order for sponsorship to work, it must be confirmed on behalf of the sponsor.
 	///
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x403e96a7,
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
 	function setCollectionSponsorCross(Tuple6 memory sponsor) public {
+=======
+	/// @dev EVM selector for this function is: 0x84a1d5a8,
+	///  or in textual repr: setCollectionSponsorCross(EthCrossAccount)
+	///  or in the expanded repr: setCollectionSponsorCross((address,uint256))
+	function setCollectionSponsorCross(EthCrossAccount memory sponsor) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		sponsor;
 		dummy = 0;
@@ -248,6 +259,7 @@
 	///  or in textual repr: collectionSponsor()
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
 	function collectionSponsor() public view returns (Tuple6 memory) {
 		require(false, stub_error);
 		dummy;
@@ -264,6 +276,12 @@
 		dummy;
 		return Tuple8(0x0000000000000000000000000000000000000000, 0);
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+	function collectionSponsor() public view returns (Tuple24 memory) {
+		require(false, stub_error);
+		dummy;
+		return Tuple24(0x0000000000000000000000000000000000000000, 0);
+>>>>>>> misk: update stubs
 	}
 
 	/// Set limits for the collection.
@@ -312,9 +330,16 @@
 
 	/// Add collection admin.
 	/// @param newAdmin Cross account administrator address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x62e3c7c2,
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
 	function addCollectionAdminCross(Tuple6 memory newAdmin) public {
+=======
+	/// @dev EVM selector for this function is: 0x859aa7d6,
+	///  or in textual repr: addCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: addCollectionAdminCross((address,uint256))
+	function addCollectionAdminCross(EthCrossAccount memory newAdmin) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		newAdmin;
 		dummy = 0;
@@ -322,9 +347,16 @@
 
 	/// Remove collection admin.
 	/// @param admin Cross account administrator address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x810d1503,
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
 	function removeCollectionAdminCross(Tuple6 memory admin) public {
+=======
+	/// @dev EVM selector for this function is: 0x6c0cd173,
+	///  or in textual repr: removeCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: removeCollectionAdminCross((address,uint256))
+	function removeCollectionAdminCross(EthCrossAccount memory admin) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		admin;
 		dummy = 0;
@@ -366,7 +398,7 @@
 	///
 	/// @param enable If "true" degenerates to nesting: {OwnerRestricted: [1, 2, 3]} else to nesting: 'Disabled'
 	/// @param collections Addresses of collections that will be available for nesting.
-	/// @dev EVM selector for this function is: 0x112d4586,
+	/// @dev EVM selector for this function is: 0x64872396,
 	///  or in textual repr: setCollectionNesting(bool,address[])
 	function setCollectionNesting(bool enable, address[] memory collections) public {
 		require(false, stub_error);
@@ -413,9 +445,16 @@
 	/// Add user to allowed list.
 	///
 	/// @param user User cross account address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xf074da88,
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
 	function addToCollectionAllowListCross(Tuple6 memory user) public {
+=======
+	/// @dev EVM selector for this function is: 0xa0184a3a,
+	///  or in textual repr: addToCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: addToCollectionAllowListCross((address,uint256))
+	function addToCollectionAllowListCross(EthCrossAccount memory user) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -435,9 +474,16 @@
 	/// Remove user from allowed list.
 	///
 	/// @param user User cross account address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xc00df45c,
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
 	function removeFromCollectionAllowListCross(Tuple6 memory user) public {
+=======
+	/// @dev EVM selector for this function is: 0x09ba452a,
+	///  or in textual repr: removeFromCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: removeFromCollectionAllowListCross((address,uint256))
+	function removeFromCollectionAllowListCross(EthCrossAccount memory user) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -471,9 +517,16 @@
 	///
 	/// @param user User cross account to verify
 	/// @return "true" if account is the owner or admin
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x5aba3351,
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
 	function isOwnerOrAdminCross(Tuple6 memory user) public view returns (bool) {
+=======
+	/// @dev EVM selector for this function is: 0x3e75a905,
+	///  or in textual repr: isOwnerOrAdminCross(EthCrossAccount)
+	///  or in the expanded repr: isOwnerOrAdminCross((address,uint256))
+	function isOwnerOrAdminCross(EthCrossAccount memory user) public view returns (bool) {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		user;
 		dummy;
@@ -499,6 +552,7 @@
 	///  or in textual repr: collectionOwner()
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
 	function collectionOwner() public view returns (Tuple6 memory) {
 		require(false, stub_error);
 		dummy;
@@ -515,6 +569,12 @@
 		dummy;
 		return Tuple8(0x0000000000000000000000000000000000000000, 0);
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+	function collectionOwner() public view returns (EthCrossAccount memory) {
+		require(false, stub_error);
+		dummy;
+		return EthCrossAccount(0x0000000000000000000000000000000000000000, 0);
+>>>>>>> misk: update stubs
 	}
 
 	/// Changes collection owner to another account
@@ -535,19 +595,33 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
+<<<<<<< HEAD
 	function collectionAdmins() public view returns (Tuple6[] memory) {
 		require(false, stub_error);
 		dummy;
 		return new Tuple6[](0);
+=======
+	function collectionAdmins() public view returns (EthCrossAccount[] memory) {
+		require(false, stub_error);
+		dummy;
+		return new EthCrossAccount[](0);
+>>>>>>> misk: update stubs
 	}
 
 	/// Changes collection owner to another account
 	///
 	/// @dev Owner can be changed only by current owner
 	/// @param newOwner new owner cross account
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xbdff793d,
 	///  or in textual repr: setOwnerCross((address,uint256))
 	function setOwnerCross(Tuple6 memory newOwner) public {
+=======
+	/// @dev EVM selector for this function is: 0xe5c9913f,
+	///  or in textual repr: setOwnerCross(EthCrossAccount)
+	///  or in the expanded repr: setOwnerCross((address,uint256))
+	function setOwnerCross(EthCrossAccount memory newOwner) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		newOwner;
 		dummy = 0;
@@ -556,12 +630,24 @@
 
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev anonymous struct
 struct Tuple19 {
+=======
+/// @dev Cross account struct
+struct EthCrossAccount {
+	address eth;
+	uint256 sub;
+}
+
+/// @dev anonymous struct
+struct Tuple24 {
+>>>>>>> misk: update stubs
 	address field_0;
 	uint256 field_1;
 }
 
+<<<<<<< HEAD
 /// @title ERC-721 Non-Fungible Token Standard, optional metadata extension
 /// @dev See https://eips.ethereum.org/EIPS/eip-721
 /// @dev the ERC-165 identifier for this interface is 0x5b5e139f
@@ -608,6 +694,8 @@
 =======
 >>>>>>> feat: Add custum signature with unlimited nesting.
 =======
+=======
+>>>>>>> misk: update stubs
 /// @dev anonymous struct
 struct Tuple21 {
 	string field_0;
@@ -717,10 +805,14 @@
 
 /// @title Unique extensions for ERC721.
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0x244543ee
 =======
 /// @dev the ERC-165 identifier for this interface is 0xcc97cb35
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+/// @dev the ERC-165 identifier for this interface is 0xb76006ac
+>>>>>>> misk: update stubs
 contract ERC721UniqueExtensions is Dummy, ERC165 {
 	/// @notice A descriptive name for a collection of NFTs in this contract
 	/// @dev EVM selector for this function is: 0x06fdde03,
@@ -746,9 +838,16 @@
 	///  operator of the current owner.
 	/// @param approved The new substrate address approved NFT controller
 	/// @param tokenId The NFT to approve
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x106fdb59,
 	///  or in textual repr: approveCross((address,uint256),uint256)
 	function approveCross(Tuple6 memory approved, uint256 tokenId) public {
+=======
+	/// @dev EVM selector for this function is: 0x0ecd0ab0,
+	///  or in textual repr: approveCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: approveCross((address,uint256),uint256)
+	function approveCross(EthCrossAccount memory approved, uint256 tokenId) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		approved;
 		tokenId;
@@ -777,6 +876,7 @@
 	/// @param tokenId The NFT to transfer
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross(EthCrossAccount,EthCrossAccount,uint256)
+	///  or in the expanded repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
 <<<<<<< HEAD
 		Tuple6 memory from,
@@ -815,9 +915,16 @@
 	///  if `to` is the zero address. Throws if `tokenId` is not a valid NFT.
 	/// @param from The current owner of the NFT
 	/// @param tokenId The NFT to transfer
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xa8106d4a,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
 	function burnFromCross(Tuple6 memory from, uint256 tokenId) public {
+=======
+	/// @dev EVM selector for this function is: 0xbb2f5a58,
+	///  or in textual repr: burnFromCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: burnFromCross((address,uint256),uint256)
+	function burnFromCross(EthCrossAccount memory from, uint256 tokenId) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		from;
 		tokenId;
@@ -873,7 +980,7 @@
 	///  should be obtained with `nextTokenId` method
 	/// @param to The new owner
 	/// @param tokenIds IDs of the minted NFTs
-	/// @dev EVM selector for this function is: 0xf9d9a5a3,
+	/// @dev EVM selector for this function is: 0x44a9945e,
 	///  or in textual repr: mintBulk(address,uint256[])
 	function mintBulk(address to, uint256[] memory tokenIds) public returns (bool) {
 		require(false, stub_error);
@@ -888,7 +995,7 @@
 	///  numbers and first number should be obtained with `nextTokenId` method
 	/// @param to The new owner
 	/// @param tokens array of pairs of token ID and token URI for minted tokens
-	/// @dev EVM selector for this function is: 0xfd4e2a99,
+	/// @dev EVM selector for this function is: 0x36543006,
 	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
 	function mintBulkWithTokenURI(address to, Tuple12[] memory tokens) public returns (bool) {
 		require(false, stub_error);
@@ -907,6 +1014,7 @@
 }
 
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev anonymous struct
 struct Tuple6 {
 	address field_0;
@@ -925,6 +1033,8 @@
 	uint256 field_1;
 }
 
+=======
+>>>>>>> misk: update stubs
 /// @title ERC-721 Non-Fungible Token Standard, optional enumeration extension
 /// @dev See https://eips.ethereum.org/EIPS/eip-721
 /// @dev the ERC-165 identifier for this interface is 0x780e9d63
modifiedpallets/refungible/src/stubs/UniqueRefungible.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueNFT.sol
+++ b/tests/src/eth/api/UniqueNFT.sol
@@ -72,6 +72,7 @@
 /// @title A contract that allows you to work with collections.
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0xb3152af3
 =======
 /// @dev the ERC-165 identifier for this interface is 0x674be726
@@ -79,6 +80,9 @@
 =======
 /// @dev the ERC-165 identifier for this interface is 0x943ee094
 >>>>>>> fix: after rebase
+=======
+/// @dev the ERC-165 identifier for this interface is 0xefe988e0
+>>>>>>> misk: update stubs
 interface Collection is Dummy, ERC165 {
 	/// Set collection property.
 	///
@@ -91,7 +95,7 @@
 	/// Set collection properties.
 	///
 	/// @param properties Vector of properties key/value pair.
-	/// @dev EVM selector for this function is: 0xf90c1ce9,
+	/// @dev EVM selector for this function is: 0x50b26b2a,
 	///  or in textual repr: setCollectionProperties((string,bytes)[])
 	function setCollectionProperties(Tuple21[] memory properties) external;
 
@@ -105,7 +109,7 @@
 	/// Delete collection properties.
 	///
 	/// @param keys Properties keys.
-	/// @dev EVM selector for this function is: 0x56d4684a,
+	/// @dev EVM selector for this function is: 0xee206ee3,
 	///  or in textual repr: deleteCollectionProperties(string[])
 	function deleteCollectionProperties(string[] memory keys) external;
 
@@ -123,7 +127,7 @@
 	///
 	/// @param keys Properties keys. Empty keys for all propertyes.
 	/// @return Vector of properties key/value pairs.
-	/// @dev EVM selector for this function is: 0x5cad7311,
+	/// @dev EVM selector for this function is: 0x285fb8e6,
 	///  or in textual repr: collectionProperties(string[])
 	function collectionProperties(string[] memory keys) external view returns (Tuple21[] memory);
 
@@ -141,9 +145,16 @@
 	/// @dev In order for sponsorship to work, it must be confirmed on behalf of the sponsor.
 	///
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x403e96a7,
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
 	function setCollectionSponsorCross(Tuple6 memory sponsor) external;
+=======
+	/// @dev EVM selector for this function is: 0x84a1d5a8,
+	///  or in textual repr: setCollectionSponsorCross(EthCrossAccount)
+	///  or in the expanded repr: setCollectionSponsorCross((address,uint256))
+	function setCollectionSponsorCross(EthCrossAccount memory sponsor) external;
+>>>>>>> misk: update stubs
 
 	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
@@ -167,7 +178,7 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
-	function collectionSponsor() external view returns (Tuple8 memory);
+	function collectionSponsor() external view returns (Tuple24 memory);
 
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
@@ -201,6 +212,7 @@
 
 	/// Add collection admin.
 	/// @param newAdmin Cross account administrator address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x62e3c7c2,
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
 	function addCollectionAdminCross(Tuple6 memory newAdmin) external;
@@ -210,6 +222,19 @@
 	/// @dev EVM selector for this function is: 0x810d1503,
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
 	function removeCollectionAdminCross(Tuple6 memory admin) external;
+=======
+	/// @dev EVM selector for this function is: 0x859aa7d6,
+	///  or in textual repr: addCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: addCollectionAdminCross((address,uint256))
+	function addCollectionAdminCross(EthCrossAccount memory newAdmin) external;
+
+	/// Remove collection admin.
+	/// @param admin Cross account administrator address.
+	/// @dev EVM selector for this function is: 0x6c0cd173,
+	///  or in textual repr: removeCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: removeCollectionAdminCross((address,uint256))
+	function removeCollectionAdminCross(EthCrossAccount memory admin) external;
+>>>>>>> misk: update stubs
 
 	/// Add collection admin.
 	/// @param newAdmin Address of the added administrator.
@@ -235,7 +260,7 @@
 	///
 	/// @param enable If "true" degenerates to nesting: {OwnerRestricted: [1, 2, 3]} else to nesting: 'Disabled'
 	/// @param collections Addresses of collections that will be available for nesting.
-	/// @dev EVM selector for this function is: 0x112d4586,
+	/// @dev EVM selector for this function is: 0x64872396,
 	///  or in textual repr: setCollectionNesting(bool,address[])
 	function setCollectionNesting(bool enable, address[] memory collections) external;
 
@@ -264,9 +289,16 @@
 	/// Add user to allowed list.
 	///
 	/// @param user User cross account address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xf074da88,
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
 	function addToCollectionAllowListCross(Tuple6 memory user) external;
+=======
+	/// @dev EVM selector for this function is: 0xa0184a3a,
+	///  or in textual repr: addToCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: addToCollectionAllowListCross((address,uint256))
+	function addToCollectionAllowListCross(EthCrossAccount memory user) external;
+>>>>>>> misk: update stubs
 
 	/// Remove the user from the allowed list.
 	///
@@ -278,9 +310,16 @@
 	/// Remove user from allowed list.
 	///
 	/// @param user User cross account address.
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xc00df45c,
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
 	function removeFromCollectionAllowListCross(Tuple6 memory user) external;
+=======
+	/// @dev EVM selector for this function is: 0x09ba452a,
+	///  or in textual repr: removeFromCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: removeFromCollectionAllowListCross((address,uint256))
+	function removeFromCollectionAllowListCross(EthCrossAccount memory user) external;
+>>>>>>> misk: update stubs
 
 	/// Switch permission for minting.
 	///
@@ -301,9 +340,16 @@
 	///
 	/// @param user User cross account to verify
 	/// @return "true" if account is the owner or admin
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x5aba3351,
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
 	function isOwnerOrAdminCross(Tuple6 memory user) external view returns (bool);
+=======
+	/// @dev EVM selector for this function is: 0x3e75a905,
+	///  or in textual repr: isOwnerOrAdminCross(EthCrossAccount)
+	///  or in the expanded repr: isOwnerOrAdminCross((address,uint256))
+	function isOwnerOrAdminCross(EthCrossAccount memory user) external view returns (bool);
+>>>>>>> misk: update stubs
 
 	/// Returns collection type
 	///
@@ -318,7 +364,7 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
-	function collectionOwner() external view returns (Tuple8 memory);
+	function collectionOwner() external view returns (EthCrossAccount memory);
 
 	/// Changes collection owner to another account
 	///
@@ -334,15 +380,38 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
+<<<<<<< HEAD
 	function collectionAdmins() external view returns (Tuple6[] memory);
+=======
+	function collectionAdmins() external view returns (EthCrossAccount[] memory);
+>>>>>>> misk: update stubs
 
 	/// Changes collection owner to another account
 	///
 	/// @dev Owner can be changed only by current owner
 	/// @param newOwner new owner cross account
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xbdff793d,
 	///  or in textual repr: setOwnerCross((address,uint256))
 	function setOwnerCross(Tuple6 memory newOwner) external;
+=======
+	/// @dev EVM selector for this function is: 0xe5c9913f,
+	///  or in textual repr: setOwnerCross(EthCrossAccount)
+	///  or in the expanded repr: setOwnerCross((address,uint256))
+	function setOwnerCross(EthCrossAccount memory newOwner) external;
+}
+
+/// @dev Cross account struct
+struct EthCrossAccount {
+	address eth;
+	uint256 sub;
+}
+
+/// @dev anonymous struct
+struct Tuple24 {
+	address field_0;
+	uint256 field_1;
+>>>>>>> misk: update stubs
 }
 
 <<<<<<< HEAD
@@ -459,10 +528,14 @@
 
 /// @title Unique extensions for ERC721.
 <<<<<<< HEAD
+<<<<<<< HEAD
 /// @dev the ERC-165 identifier for this interface is 0x244543ee
 =======
 /// @dev the ERC-165 identifier for this interface is 0xcc97cb35
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+/// @dev the ERC-165 identifier for this interface is 0xb76006ac
+>>>>>>> misk: update stubs
 interface ERC721UniqueExtensions is Dummy, ERC165 {
 	/// @notice A descriptive name for a collection of NFTs in this contract
 	/// @dev EVM selector for this function is: 0x06fdde03,
@@ -480,9 +553,16 @@
 	///  operator of the current owner.
 	/// @param approved The new substrate address approved NFT controller
 	/// @param tokenId The NFT to approve
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0x106fdb59,
 	///  or in textual repr: approveCross((address,uint256),uint256)
 	function approveCross(Tuple6 memory approved, uint256 tokenId) external;
+=======
+	/// @dev EVM selector for this function is: 0x0ecd0ab0,
+	///  or in textual repr: approveCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: approveCross((address,uint256),uint256)
+	function approveCross(EthCrossAccount memory approved, uint256 tokenId) external;
+>>>>>>> misk: update stubs
 
 	/// @notice Transfer ownership of an NFT
 	/// @dev Throws unless `msg.sender` is the current owner. Throws if `to`
@@ -501,6 +581,7 @@
 	/// @param tokenId The NFT to transfer
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross(EthCrossAccount,EthCrossAccount,uint256)
+	///  or in the expanded repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
 <<<<<<< HEAD
 		Tuple6 memory from,
@@ -528,9 +609,16 @@
 	///  if `to` is the zero address. Throws if `tokenId` is not a valid NFT.
 	/// @param from The current owner of the NFT
 	/// @param tokenId The NFT to transfer
+<<<<<<< HEAD
 	/// @dev EVM selector for this function is: 0xa8106d4a,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
 	function burnFromCross(Tuple6 memory from, uint256 tokenId) external;
+=======
+	/// @dev EVM selector for this function is: 0xbb2f5a58,
+	///  or in textual repr: burnFromCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: burnFromCross((address,uint256),uint256)
+	function burnFromCross(EthCrossAccount memory from, uint256 tokenId) external;
+>>>>>>> misk: update stubs
 
 	/// @notice Returns next free NFT ID.
 	/// @dev EVM selector for this function is: 0x75794a3c,
@@ -565,7 +653,7 @@
 	///  should be obtained with `nextTokenId` method
 	/// @param to The new owner
 	/// @param tokenIds IDs of the minted NFTs
-	/// @dev EVM selector for this function is: 0xf9d9a5a3,
+	/// @dev EVM selector for this function is: 0x44a9945e,
 	///  or in textual repr: mintBulk(address,uint256[])
 	function mintBulk(address to, uint256[] memory tokenIds) external returns (bool);
 
@@ -574,7 +662,7 @@
 	///  numbers and first number should be obtained with `nextTokenId` method
 	/// @param to The new owner
 	/// @param tokens array of pairs of token ID and token URI for minted tokens
-	/// @dev EVM selector for this function is: 0xfd4e2a99,
+	/// @dev EVM selector for this function is: 0x36543006,
 	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
 	function mintBulkWithTokenURI(address to, Tuple12[] memory tokens) external returns (bool);
 }
@@ -586,6 +674,7 @@
 	string field_1;
 }
 
+<<<<<<< HEAD
 /// @dev anonymous struct
 struct Tuple8 {
 	address field_0;
@@ -598,6 +687,8 @@
 	uint256 field_1;
 }
 
+=======
+>>>>>>> misk: update stubs
 /// @title ERC-721 Non-Fungible Token Standard, optional enumeration extension
 /// @dev See https://eips.ethereum.org/EIPS/eip-721
 /// @dev the ERC-165 identifier for this interface is 0x780e9d63
modifiedtests/src/eth/api/UniqueRefungible.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueRefungible.sol
+++ b/tests/src/eth/api/UniqueRefungible.sol
@@ -85,7 +85,7 @@
 	/// @param properties Vector of properties key/value pair.
 	/// @dev EVM selector for this function is: 0x50b26b2a,
 	///  or in textual repr: setCollectionProperties((string,bytes)[])
-	function setCollectionProperties(Tuple19[] memory properties) external;
+	function setCollectionProperties(Tuple20[] memory properties) external;
 
 	/// Delete collection property.
 	///
@@ -117,7 +117,7 @@
 	/// @return Vector of properties key/value pairs.
 	/// @dev EVM selector for this function is: 0x285fb8e6,
 	///  or in textual repr: collectionProperties(string[])
-	function collectionProperties(string[] memory keys) external view returns (Tuple19[] memory);
+	function collectionProperties(string[] memory keys) external view returns (Tuple20[] memory);
 
 	/// Set the sponsor of the collection.
 	///
@@ -134,8 +134,14 @@
 	///
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
 	/// @dev EVM selector for this function is: 0x84a1d5a8,
+<<<<<<< HEAD
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
 	function setCollectionSponsorCross(Tuple6 memory sponsor) external;
+=======
+	///  or in textual repr: setCollectionSponsorCross(EthCrossAccount)
+	///  or in the expanded repr: setCollectionSponsorCross((address,uint256))
+	function setCollectionSponsorCross(EthCrossAccount memory sponsor) external;
+>>>>>>> misk: update stubs
 
 	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
@@ -159,7 +165,11 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
+<<<<<<< HEAD
 	function collectionSponsor() external view returns (Tuple6 memory);
+=======
+	function collectionSponsor() external view returns (Tuple23 memory);
+>>>>>>> misk: update stubs
 
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
@@ -194,14 +204,26 @@
 	/// Add collection admin.
 	/// @param newAdmin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x859aa7d6,
+<<<<<<< HEAD
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
 	function addCollectionAdminCross(Tuple6 memory newAdmin) external;
+=======
+	///  or in textual repr: addCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: addCollectionAdminCross((address,uint256))
+	function addCollectionAdminCross(EthCrossAccount memory newAdmin) external;
+>>>>>>> misk: update stubs
 
 	/// Remove collection admin.
 	/// @param admin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x6c0cd173,
+<<<<<<< HEAD
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
 	function removeCollectionAdminCross(Tuple6 memory admin) external;
+=======
+	///  or in textual repr: removeCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: removeCollectionAdminCross((address,uint256))
+	function removeCollectionAdminCross(EthCrossAccount memory admin) external;
+>>>>>>> misk: update stubs
 
 	/// Add collection admin.
 	/// @param newAdmin Address of the added administrator.
@@ -257,8 +279,14 @@
 	///
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0xa0184a3a,
+<<<<<<< HEAD
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
 	function addToCollectionAllowListCross(Tuple6 memory user) external;
+=======
+	///  or in textual repr: addToCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: addToCollectionAllowListCross((address,uint256))
+	function addToCollectionAllowListCross(EthCrossAccount memory user) external;
+>>>>>>> misk: update stubs
 
 	/// Remove the user from the allowed list.
 	///
@@ -271,8 +299,14 @@
 	///
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0x09ba452a,
+<<<<<<< HEAD
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
 	function removeFromCollectionAllowListCross(Tuple6 memory user) external;
+=======
+	///  or in textual repr: removeFromCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: removeFromCollectionAllowListCross((address,uint256))
+	function removeFromCollectionAllowListCross(EthCrossAccount memory user) external;
+>>>>>>> misk: update stubs
 
 	/// Switch permission for minting.
 	///
@@ -294,8 +328,14 @@
 	/// @param user User cross account to verify
 	/// @return "true" if account is the owner or admin
 	/// @dev EVM selector for this function is: 0x3e75a905,
+<<<<<<< HEAD
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
 	function isOwnerOrAdminCross(Tuple6 memory user) external view returns (bool);
+=======
+	///  or in textual repr: isOwnerOrAdminCross(EthCrossAccount)
+	///  or in the expanded repr: isOwnerOrAdminCross((address,uint256))
+	function isOwnerOrAdminCross(EthCrossAccount memory user) external view returns (bool);
+>>>>>>> misk: update stubs
 
 	/// Returns collection type
 	///
@@ -306,11 +346,15 @@
 
 	/// Get collection owner.
 	///
-	/// @return Tuble with sponsor address and his substrate mirror.
+	/// @return Tuple with sponsor address and his substrate mirror.
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
+<<<<<<< HEAD
 	function collectionOwner() external view returns (Tuple6 memory);
+=======
+	function collectionOwner() external view returns (EthCrossAccount memory);
+>>>>>>> misk: update stubs
 
 	/// Changes collection owner to another account
 	///
@@ -326,19 +370,41 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
+<<<<<<< HEAD
 	function collectionAdmins() external view returns (Tuple6[] memory);
+=======
+	function collectionAdmins() external view returns (EthCrossAccount[] memory);
+>>>>>>> misk: update stubs
 
 	/// Changes collection owner to another account
 	///
 	/// @dev Owner can be changed only by current owner
 	/// @param newOwner new owner cross account
 	/// @dev EVM selector for this function is: 0xe5c9913f,
+<<<<<<< HEAD
 	///  or in textual repr: setOwnerCross((address,uint256))
 	function setOwnerCross(Tuple6 memory newOwner) external;
+=======
+	///  or in textual repr: setOwnerCross(EthCrossAccount)
+	///  or in the expanded repr: setOwnerCross((address,uint256))
+	function setOwnerCross(EthCrossAccount memory newOwner) external;
+}
+
+/// @dev Cross account struct
+struct EthCrossAccount {
+	address eth;
+	uint256 sub;
+}
+
+/// @dev anonymous struct
+struct Tuple23 {
+	address field_0;
+	uint256 field_1;
+>>>>>>> misk: update stubs
 }
 
 /// @dev anonymous struct
-struct Tuple19 {
+struct Tuple20 {
 	string field_0;
 	bytes field_1;
 }
@@ -465,10 +531,16 @@
 	/// @param to The new owner
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0xd5cf430b,
-	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
+	///  or in textual repr: transferFromCross(EthCrossAccount,EthCrossAccount,uint256)
+	///  or in the expanded repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
+<<<<<<< HEAD
 		Tuple6 memory from,
 		Tuple6 memory to,
+=======
+		EthCrossAccount memory from,
+		EthCrossAccount memory to,
+>>>>>>> misk: update stubs
 		uint256 tokenId
 	) external;
 
@@ -491,14 +563,21 @@
 	/// @param from The current owner of the RFT
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
+<<<<<<< HEAD
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
 	function burnFromCross(Tuple6 memory from, uint256 tokenId) external;
+=======
+	///  or in textual repr: burnFromCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: burnFromCross((address,uint256),uint256)
+	function burnFromCross(EthCrossAccount memory from, uint256 tokenId) external;
+>>>>>>> misk: update stubs
 
 	/// @notice Returns next free RFT ID.
 	/// @dev EVM selector for this function is: 0x75794a3c,
 	///  or in textual repr: nextTokenId()
 	function nextTokenId() external view returns (uint256);
 
+<<<<<<< HEAD
 	// /// @notice Function to mint multiple tokens.
 	// /// @dev `tokenIds` should be an array of consecutive numbers and first number
 	// ///  should be obtained with `nextTokenId` method
@@ -516,6 +595,25 @@
 	// /// @dev EVM selector for this function is: 0x36543006,
 	// ///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
 	// function mintBulkWithTokenURI(address to, Tuple8[] memory tokens) external returns (bool);
+=======
+	/// @notice Function to mint multiple tokens.
+	/// @dev `tokenIds` should be an array of consecutive numbers and first number
+	///  should be obtained with `nextTokenId` method
+	/// @param to The new owner
+	/// @param tokenIds IDs of the minted RFTs
+	/// @dev EVM selector for this function is: 0x44a9945e,
+	///  or in textual repr: mintBulk(address,uint256[])
+	function mintBulk(address to, uint256[] memory tokenIds) external returns (bool);
+
+	/// @notice Function to mint multiple tokens with the given tokenUris.
+	/// @dev `tokenIds` is array of pairs of token ID and token URI. Token IDs should be consecutive
+	///  numbers and first number should be obtained with `nextTokenId` method
+	/// @param to The new owner
+	/// @param tokens array of pairs of token ID and token URI for minted tokens
+	/// @dev EVM selector for this function is: 0x36543006,
+	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
+	function mintBulkWithTokenURI(address to, Tuple11[] memory tokens) external returns (bool);
+>>>>>>> misk: update stubs
 
 	/// Returns EVM address for refungible token
 	///
@@ -526,17 +624,24 @@
 }
 
 /// @dev anonymous struct
+<<<<<<< HEAD
 struct Tuple8 {
+=======
+struct Tuple11 {
+>>>>>>> misk: update stubs
 	uint256 field_0;
 	string field_1;
 }
 
+<<<<<<< HEAD
 /// @dev anonymous struct
 struct Tuple6 {
 	address field_0;
 	uint256 field_1;
 }
 
+=======
+>>>>>>> misk: update stubs
 /// @title ERC-721 Non-Fungible Token Standard, optional enumeration extension
 /// @dev See https://eips.ethereum.org/EIPS/eip-721
 /// @dev the ERC-165 identifier for this interface is 0x780e9d63
modifiedtests/src/eth/fungibleAbi.jsondiffbeforeafterboth
62 "inputs": [62 "inputs": [
63 {63 {
64 "components": [64 "components": [
65<<<<<<< HEAD
65 { "internalType": "address", "name": "field_0", "type": "address" },66 { "internalType": "address", "name": "field_0", "type": "address" },
66 { "internalType": "uint256", "name": "field_1", "type": "uint256" }67 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
68=======
69 { "internalType": "address", "name": "eth", "type": "address" },
70 { "internalType": "uint256", "name": "sub", "type": "uint256" }
71>>>>>>> misk: update stubs
67 ],72 ],
68 "internalType": "struct Tuple6",73 "internalType": "struct EthCrossAccount",
69 "name": "newAdmin",74 "name": "newAdmin",
70 "type": "tuple"75 "type": "tuple"
71 }76 }
88 "inputs": [93 "inputs": [
89 {94 {
90 "components": [95 "components": [
96<<<<<<< HEAD
91 { "internalType": "address", "name": "field_0", "type": "address" },97 { "internalType": "address", "name": "field_0", "type": "address" },
92 { "internalType": "uint256", "name": "field_1", "type": "uint256" }98 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
99=======
100 { "internalType": "address", "name": "eth", "type": "address" },
101 { "internalType": "uint256", "name": "sub", "type": "uint256" }
102>>>>>>> misk: update stubs
93 ],103 ],
94 "internalType": "struct Tuple6",104 "internalType": "struct EthCrossAccount",
95 "name": "user",105 "name": "user",
96 "type": "tuple"106 "type": "tuple"
97 }107 }
134 "inputs": [144 "inputs": [
135 {145 {
136 "components": [146 "components": [
147<<<<<<< HEAD
137 { "internalType": "address", "name": "field_0", "type": "address" },148 { "internalType": "address", "name": "field_0", "type": "address" },
138 { "internalType": "uint256", "name": "field_1", "type": "uint256" }149 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
150=======
151 { "internalType": "address", "name": "eth", "type": "address" },
152 { "internalType": "uint256", "name": "sub", "type": "uint256" }
153>>>>>>> misk: update stubs
139 ],154 ],
140 "internalType": "struct Tuple6",155 "internalType": "struct EthCrossAccount",
141 "name": "spender",156 "name": "spender",
142 "type": "tuple"157 "type": "tuple"
143 },158 },
171 "inputs": [186 "inputs": [
172 {187 {
173 "components": [188 "components": [
189<<<<<<< HEAD
174 { "internalType": "address", "name": "field_0", "type": "address" },190 { "internalType": "address", "name": "field_0", "type": "address" },
175 { "internalType": "uint256", "name": "field_1", "type": "uint256" }191 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
192=======
193 { "internalType": "address", "name": "eth", "type": "address" },
194 { "internalType": "uint256", "name": "sub", "type": "uint256" }
195>>>>>>> misk: update stubs
176 ],196 ],
177 "internalType": "struct Tuple6",197 "internalType": "struct EthCrossAccount",
178 "name": "from",198 "name": "from",
179 "type": "tuple"199 "type": "tuple"
180 },200 },
181 { "internalType": "uint256", "name": "amount", "type": "uint256" }201 { "internalType": "uint256", "name": "amount", "type": "uint256" }
182 ],202 ],
183 "name": "burnFromCross",203 "name": "burnFromCross",
184 "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],204 "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
205<<<<<<< HEAD
185 "stateMutability": "nonpayable",206 "stateMutability": "nonpayable",
186 "type": "function"207 "type": "function"
187 },208 },
191 ],212 ],
192 "name": "changeCollectionOwner",213 "name": "changeCollectionOwner",
193 "outputs": [],214 "outputs": [],
215=======
216>>>>>>> misk: update stubs
194 "stateMutability": "nonpayable",217 "stateMutability": "nonpayable",
195 "type": "function"218 "type": "function"
196 },219 },
200 "outputs": [223 "outputs": [
201 {224 {
202 "components": [225 "components": [
226<<<<<<< HEAD
203 { "internalType": "address", "name": "field_0", "type": "address" },227 { "internalType": "address", "name": "field_0", "type": "address" },
204 { "internalType": "uint256", "name": "field_1", "type": "uint256" }228 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
229=======
230 { "internalType": "address", "name": "eth", "type": "address" },
231 { "internalType": "uint256", "name": "sub", "type": "uint256" }
232>>>>>>> misk: update stubs
205 ],233 ],
206 "internalType": "struct Tuple6[]",234 "internalType": "struct EthCrossAccount[]",
207 "name": "",235 "name": "",
208 "type": "tuple[]"236 "type": "tuple[]"
209 }237 }
217 "outputs": [245 "outputs": [
218 {246 {
219 "components": [247 "components": [
248<<<<<<< HEAD
220 { "internalType": "address", "name": "field_0", "type": "address" },249 { "internalType": "address", "name": "field_0", "type": "address" },
221 { "internalType": "uint256", "name": "field_1", "type": "uint256" }250 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
251=======
252 { "internalType": "address", "name": "eth", "type": "address" },
253 { "internalType": "uint256", "name": "sub", "type": "uint256" }
254>>>>>>> misk: update stubs
222 ],255 ],
223 "internalType": "struct Tuple6",256 "internalType": "struct EthCrossAccount",
224 "name": "",257 "name": "",
225 "type": "tuple"258 "type": "tuple"
226 }259 }
239 { "internalType": "string", "name": "field_0", "type": "string" },272 { "internalType": "string", "name": "field_0", "type": "string" },
240 { "internalType": "bytes", "name": "field_1", "type": "bytes" }273 { "internalType": "bytes", "name": "field_1", "type": "bytes" }
241 ],274 ],
242 "internalType": "struct Tuple10[]",275 "internalType": "struct Tuple14[]",
243 "name": "",276 "name": "",
244 "type": "tuple[]"277 "type": "tuple[]"
245 }278 }
263 { "internalType": "address", "name": "field_0", "type": "address" },296 { "internalType": "address", "name": "field_0", "type": "address" },
264 { "internalType": "uint256", "name": "field_1", "type": "uint256" }297 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
265 ],298 ],
266 "internalType": "struct Tuple6",299 "internalType": "struct Tuple8",
267 "name": "",300 "name": "",
268 "type": "tuple"301 "type": "tuple"
269 }302 }
328 "inputs": [361 "inputs": [
329 {362 {
330 "components": [363 "components": [
364<<<<<<< HEAD
331 { "internalType": "address", "name": "field_0", "type": "address" },365 { "internalType": "address", "name": "field_0", "type": "address" },
332 { "internalType": "uint256", "name": "field_1", "type": "uint256" }366 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
367=======
368 { "internalType": "address", "name": "eth", "type": "address" },
369 { "internalType": "uint256", "name": "sub", "type": "uint256" }
370>>>>>>> misk: update stubs
333 ],371 ],
334 "internalType": "struct Tuple6",372 "internalType": "struct EthCrossAccount",
335 "name": "user",373 "name": "user",
336 "type": "tuple"374 "type": "tuple"
337 }375 }
358 { "internalType": "address", "name": "field_0", "type": "address" },396 { "internalType": "address", "name": "field_0", "type": "address" },
359 { "internalType": "uint256", "name": "field_1", "type": "uint256" }397 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
360 ],398 ],
361 "internalType": "struct Tuple6[]",399 "internalType": "struct Tuple8[]",
362 "name": "amounts",400 "name": "amounts",
363 "type": "tuple[]"401 "type": "tuple[]"
364 }402 }
388 "inputs": [426 "inputs": [
389 {427 {
390 "components": [428 "components": [
429<<<<<<< HEAD
391 { "internalType": "address", "name": "field_0", "type": "address" },430 { "internalType": "address", "name": "field_0", "type": "address" },
392 { "internalType": "uint256", "name": "field_1", "type": "uint256" }431 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
432=======
433 { "internalType": "address", "name": "eth", "type": "address" },
434 { "internalType": "uint256", "name": "sub", "type": "uint256" }
435>>>>>>> misk: update stubs
393 ],436 ],
394 "internalType": "struct Tuple6",437 "internalType": "struct EthCrossAccount",
395 "name": "admin",438 "name": "admin",
396 "type": "tuple"439 "type": "tuple"
397 }440 }
421 "inputs": [464 "inputs": [
422 {465 {
423 "components": [466 "components": [
467<<<<<<< HEAD
424 { "internalType": "address", "name": "field_0", "type": "address" },468 { "internalType": "address", "name": "field_0", "type": "address" },
425 { "internalType": "uint256", "name": "field_1", "type": "uint256" }469 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
470=======
471 { "internalType": "address", "name": "eth", "type": "address" },
472 { "internalType": "uint256", "name": "sub", "type": "uint256" }
473>>>>>>> misk: update stubs
426 ],474 ],
427 "internalType": "struct Tuple6",475 "internalType": "struct EthCrossAccount",
428 "name": "user",476 "name": "user",
429 "type": "tuple"477 "type": "tuple"
430 }478 }
496 { "internalType": "string", "name": "field_0", "type": "string" },544 { "internalType": "string", "name": "field_0", "type": "string" },
497 { "internalType": "bytes", "name": "field_1", "type": "bytes" }545 { "internalType": "bytes", "name": "field_1", "type": "bytes" }
498 ],546 ],
499 "internalType": "struct Tuple10[]",547 "internalType": "struct Tuple14[]",
500 "name": "properties",548 "name": "properties",
501 "type": "tuple[]"549 "type": "tuple[]"
502 }550 }
529 "inputs": [577 "inputs": [
530 {578 {
531 "components": [579 "components": [
580<<<<<<< HEAD
532 { "internalType": "address", "name": "field_0", "type": "address" },581 { "internalType": "address", "name": "field_0", "type": "address" },
533 { "internalType": "uint256", "name": "field_1", "type": "uint256" }582 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
583=======
584 { "internalType": "address", "name": "eth", "type": "address" },
585 { "internalType": "uint256", "name": "sub", "type": "uint256" }
586>>>>>>> misk: update stubs
534 ],587 ],
535 "internalType": "struct Tuple6",588 "internalType": "struct EthCrossAccount",
536 "name": "sponsor",589 "name": "sponsor",
537 "type": "tuple"590 "type": "tuple"
538 }591 }
544 },597 },
545 {598 {
546 "inputs": [599 "inputs": [
600<<<<<<< HEAD
547 {601 {
548 "components": [602 "components": [
549 { "internalType": "address", "name": "field_0", "type": "address" },603 { "internalType": "address", "name": "field_0", "type": "address" },
550 { "internalType": "uint256", "name": "field_1", "type": "uint256" }604 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
605=======
606 { "internalType": "address", "name": "newOwner", "type": "address" }
607 ],
608 "name": "setOwner",
609 "outputs": [],
610 "stateMutability": "nonpayable",
611 "type": "function"
612 },
613 {
614 "inputs": [
615 {
616 "components": [
617 { "internalType": "address", "name": "eth", "type": "address" },
618 { "internalType": "uint256", "name": "sub", "type": "uint256" }
619>>>>>>> misk: update stubs
551 ],620 ],
552 "internalType": "struct Tuple6",621 "internalType": "struct EthCrossAccount",
553 "name": "newOwner",622 "name": "newOwner",
554 "type": "tuple"623 "type": "tuple"
555 }624 }
607 "inputs": [676 "inputs": [
608 {677 {
609 "components": [678 "components": [
679<<<<<<< HEAD
610 { "internalType": "address", "name": "field_0", "type": "address" },680 { "internalType": "address", "name": "field_0", "type": "address" },
611 { "internalType": "uint256", "name": "field_1", "type": "uint256" }681 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
682=======
683 { "internalType": "address", "name": "eth", "type": "address" },
684 { "internalType": "uint256", "name": "sub", "type": "uint256" }
685>>>>>>> misk: update stubs
612 ],686 ],
613 "internalType": "struct Tuple6",687 "internalType": "struct EthCrossAccount",
614 "name": "from",688 "name": "from",
615 "type": "tuple"689 "type": "tuple"
616 },690 },
617 {691 {
618 "components": [692 "components": [
693<<<<<<< HEAD
619 { "internalType": "address", "name": "field_0", "type": "address" },694 { "internalType": "address", "name": "field_0", "type": "address" },
620 { "internalType": "uint256", "name": "field_1", "type": "uint256" }695 { "internalType": "uint256", "name": "field_1", "type": "uint256" }
696=======
697 { "internalType": "address", "name": "eth", "type": "address" },
698 { "internalType": "uint256", "name": "sub", "type": "uint256" }
699>>>>>>> misk: update stubs
621 ],700 ],
622 "internalType": "struct Tuple6",701 "internalType": "struct EthCrossAccount",
623 "name": "to",702 "name": "to",
624 "type": "tuple"703 "type": "tuple"
625 },704 },
modifiedtests/src/eth/nonFungibleAbi.jsondiffbeforeafterboth
--- a/tests/src/eth/nonFungibleAbi.json
+++ b/tests/src/eth/nonFungibleAbi.json
@@ -93,10 +93,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "newAdmin",
         "type": "tuple"
       }
@@ -119,10 +123,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -155,10 +163,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "approved",
         "type": "tuple"
       },
@@ -201,10 +213,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "from",
         "type": "tuple"
       },
@@ -230,10 +246,14 @@
     "outputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6[]",
+=======
+        "internalType": "struct EthCrossAccount[]",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple[]"
       }
@@ -247,11 +267,12 @@
     "outputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
 =======
         "internalType": "struct Tuple19",
@@ -259,6 +280,9 @@
 =======
         "internalType": "struct Tuple8",
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple"
       }
@@ -319,6 +343,7 @@
         ],
 <<<<<<< HEAD
 <<<<<<< HEAD
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
 =======
         "internalType": "struct Tuple19",
@@ -326,6 +351,9 @@
 =======
         "internalType": "struct Tuple8",
 >>>>>>> feat: Add custum signature with unlimited nesting.
+=======
+        "internalType": "struct Tuple24",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple"
       }
@@ -428,10 +456,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -556,10 +588,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "admin",
         "type": "tuple"
       }
@@ -589,10 +625,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -745,10 +785,14 @@
     "inputs": [
       {
         "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "sponsor",
         "type": "tuple"
       }
@@ -785,6 +829,7 @@
       {
         "components": [
 <<<<<<< HEAD
+<<<<<<< HEAD
           { "internalType": "string", "name": "field_0", "type": "string" },
           { "internalType": "bytes", "name": "field_1", "type": "bytes" }
 =======
@@ -795,6 +840,14 @@
         "internalType": "struct Tuple19[]",
         "name": "properties",
         "type": "tuple[]"
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+        "name": "newOwner",
+        "type": "tuple"
+>>>>>>> misk: update stubs
       }
     ],
     "name": "setProperties",
modifiedtests/src/eth/reFungibleAbi.jsondiffbeforeafterboth
--- a/tests/src/eth/reFungibleAbi.json
+++ b/tests/src/eth/reFungibleAbi.json
@@ -93,10 +93,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "newAdmin",
         "type": "tuple"
       }
@@ -119,10 +126,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -183,10 +197,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "from",
         "type": "tuple"
       },
@@ -212,10 +233,17 @@
     "outputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6[]",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount[]",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple[]"
       }
@@ -229,10 +257,17 @@
     "outputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple"
       }
@@ -251,7 +286,7 @@
           { "internalType": "string", "name": "field_0", "type": "string" },
           { "internalType": "bytes", "name": "field_1", "type": "bytes" }
         ],
-        "internalType": "struct Tuple19[]",
+        "internalType": "struct Tuple20[]",
         "name": "",
         "type": "tuple[]"
       }
@@ -275,7 +310,11 @@
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
+<<<<<<< HEAD
         "internalType": "struct Tuple6",
+=======
+        "internalType": "struct Tuple23",
+>>>>>>> misk: update stubs
         "name": "",
         "type": "tuple"
       }
@@ -369,10 +408,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -383,23 +429,68 @@
     "type": "function"
   },
   {
+<<<<<<< HEAD
     "inputs": [{ "internalType": "address", "name": "to", "type": "address" }],
     "name": "mint",
     "outputs": [{ "internalType": "uint256", "name": "", "type": "uint256" }],
+=======
+    "inputs": [
+      { "internalType": "address", "name": "to", "type": "address" },
+      { "internalType": "uint256", "name": "tokenId", "type": "uint256" }
+    ],
+    "name": "mint",
+    "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
+>>>>>>> misk: update stubs
     "stateMutability": "nonpayable",
     "type": "function"
   },
   {
     "inputs": [
       { "internalType": "address", "name": "to", "type": "address" },
+<<<<<<< HEAD
       { "internalType": "string", "name": "tokenUri", "type": "string" }
     ],
     "name": "mintWithTokenURI",
     "outputs": [{ "internalType": "uint256", "name": "", "type": "uint256" }],
+=======
+      { "internalType": "uint256[]", "name": "tokenIds", "type": "uint256[]" }
+    ],
+    "name": "mintBulk",
+    "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
     "stateMutability": "nonpayable",
     "type": "function"
   },
   {
+    "inputs": [
+      { "internalType": "address", "name": "to", "type": "address" },
+      {
+        "components": [
+          { "internalType": "uint256", "name": "field_0", "type": "uint256" },
+          { "internalType": "string", "name": "field_1", "type": "string" }
+        ],
+        "internalType": "struct Tuple11[]",
+        "name": "tokens",
+        "type": "tuple[]"
+      }
+    ],
+    "name": "mintBulkWithTokenURI",
+    "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
+    "stateMutability": "nonpayable",
+    "type": "function"
+  },
+  {
+    "inputs": [
+      { "internalType": "address", "name": "to", "type": "address" },
+      { "internalType": "uint256", "name": "tokenId", "type": "uint256" },
+      { "internalType": "string", "name": "tokenUri", "type": "string" }
+    ],
+    "name": "mintWithTokenURI",
+    "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
+>>>>>>> misk: update stubs
+    "stateMutability": "nonpayable",
+    "type": "function"
+  },
+  {
     "inputs": [],
     "name": "mintingFinished",
     "outputs": [{ "internalType": "bool", "name": "", "type": "bool" }],
@@ -452,10 +543,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "admin",
         "type": "tuple"
       }
@@ -485,10 +583,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "user",
         "type": "tuple"
       }
@@ -593,7 +698,7 @@
           { "internalType": "string", "name": "field_0", "type": "string" },
           { "internalType": "bytes", "name": "field_1", "type": "bytes" }
         ],
-        "internalType": "struct Tuple19[]",
+        "internalType": "struct Tuple20[]",
         "name": "properties",
         "type": "tuple[]"
       }
@@ -626,10 +731,17 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "sponsor",
         "type": "tuple"
       }
@@ -641,6 +753,7 @@
   },
   {
     "inputs": [
+<<<<<<< HEAD
       {
         "components": [
           { "internalType": "address", "name": "field_0", "type": "address" },
@@ -650,6 +763,9 @@
         "name": "newOwner",
         "type": "tuple"
       }
+=======
+      { "internalType": "address", "name": "newOwner", "type": "address" }
+>>>>>>> misk: update stubs
     ],
     "name": "setOwnerCross",
     "outputs": [],
@@ -661,12 +777,21 @@
       { "internalType": "uint256", "name": "tokenId", "type": "uint256" },
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "string", "name": "field_0", "type": "string" },
           { "internalType": "bytes", "name": "field_1", "type": "bytes" }
         ],
         "internalType": "struct Tuple19[]",
         "name": "properties",
         "type": "tuple[]"
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+        "name": "newOwner",
+        "type": "tuple"
+>>>>>>> misk: update stubs
       }
     ],
     "name": "setProperties",
@@ -782,19 +907,33 @@
     "inputs": [
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "from",
         "type": "tuple"
       },
       {
         "components": [
+<<<<<<< HEAD
           { "internalType": "address", "name": "field_0", "type": "address" },
           { "internalType": "uint256", "name": "field_1", "type": "uint256" }
         ],
         "internalType": "struct Tuple6",
+=======
+          { "internalType": "address", "name": "eth", "type": "address" },
+          { "internalType": "uint256", "name": "sub", "type": "uint256" }
+        ],
+        "internalType": "struct EthCrossAccount",
+>>>>>>> misk: update stubs
         "name": "to",
         "type": "tuple"
       },
--- a/pallets/refungible/src/stubs/UniqueRefungible.sol
+++ b/pallets/refungible/src/stubs/UniqueRefungible.sol
@@ -124,7 +124,7 @@
 	/// @param properties Vector of properties key/value pair.
 	/// @dev EVM selector for this function is: 0x50b26b2a,
 	///  or in textual repr: setCollectionProperties((string,bytes)[])
-	function setCollectionProperties(Tuple19[] memory properties) public {
+	function setCollectionProperties(Tuple20[] memory properties) public {
 		require(false, stub_error);
 		properties;
 		dummy = 0;
@@ -173,11 +173,11 @@
 	/// @return Vector of properties key/value pairs.
 	/// @dev EVM selector for this function is: 0x285fb8e6,
 	///  or in textual repr: collectionProperties(string[])
-	function collectionProperties(string[] memory keys) public view returns (Tuple19[] memory) {
+	function collectionProperties(string[] memory keys) public view returns (Tuple20[] memory) {
 		require(false, stub_error);
 		keys;
 		dummy;
-		return new Tuple19[](0);
+		return new Tuple20[](0);
 	}
 
 	/// Set the sponsor of the collection.
@@ -199,8 +199,14 @@
 	///
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
 	/// @dev EVM selector for this function is: 0x84a1d5a8,
+<<<<<<< HEAD
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
 	function setCollectionSponsorCross(Tuple6 memory sponsor) public {
+=======
+	///  or in textual repr: setCollectionSponsorCross(EthCrossAccount)
+	///  or in the expanded repr: setCollectionSponsorCross((address,uint256))
+	function setCollectionSponsorCross(EthCrossAccount memory sponsor) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		sponsor;
 		dummy = 0;
@@ -238,10 +244,17 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
+<<<<<<< HEAD
 	function collectionSponsor() public view returns (Tuple6 memory) {
 		require(false, stub_error);
 		dummy;
 		return Tuple6(0x0000000000000000000000000000000000000000, 0);
+=======
+	function collectionSponsor() public view returns (Tuple23 memory) {
+		require(false, stub_error);
+		dummy;
+		return Tuple23(0x0000000000000000000000000000000000000000, 0);
+>>>>>>> misk: update stubs
 	}
 
 	/// Set limits for the collection.
@@ -291,8 +304,14 @@
 	/// Add collection admin.
 	/// @param newAdmin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x859aa7d6,
+<<<<<<< HEAD
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
 	function addCollectionAdminCross(Tuple6 memory newAdmin) public {
+=======
+	///  or in textual repr: addCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: addCollectionAdminCross((address,uint256))
+	function addCollectionAdminCross(EthCrossAccount memory newAdmin) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		newAdmin;
 		dummy = 0;
@@ -301,8 +320,14 @@
 	/// Remove collection admin.
 	/// @param admin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x6c0cd173,
+<<<<<<< HEAD
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
 	function removeCollectionAdminCross(Tuple6 memory admin) public {
+=======
+	///  or in textual repr: removeCollectionAdminCross(EthCrossAccount)
+	///  or in the expanded repr: removeCollectionAdminCross((address,uint256))
+	function removeCollectionAdminCross(EthCrossAccount memory admin) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		admin;
 		dummy = 0;
@@ -392,8 +417,14 @@
 	///
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0xa0184a3a,
+<<<<<<< HEAD
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
 	function addToCollectionAllowListCross(Tuple6 memory user) public {
+=======
+	///  or in textual repr: addToCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: addToCollectionAllowListCross((address,uint256))
+	function addToCollectionAllowListCross(EthCrossAccount memory user) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -414,8 +445,14 @@
 	///
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0x09ba452a,
+<<<<<<< HEAD
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
 	function removeFromCollectionAllowListCross(Tuple6 memory user) public {
+=======
+	///  or in textual repr: removeFromCollectionAllowListCross(EthCrossAccount)
+	///  or in the expanded repr: removeFromCollectionAllowListCross((address,uint256))
+	function removeFromCollectionAllowListCross(EthCrossAccount memory user) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -450,8 +487,14 @@
 	/// @param user User cross account to verify
 	/// @return "true" if account is the owner or admin
 	/// @dev EVM selector for this function is: 0x3e75a905,
+<<<<<<< HEAD
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
 	function isOwnerOrAdminCross(Tuple6 memory user) public view returns (bool) {
+=======
+	///  or in textual repr: isOwnerOrAdminCross(EthCrossAccount)
+	///  or in the expanded repr: isOwnerOrAdminCross((address,uint256))
+	function isOwnerOrAdminCross(EthCrossAccount memory user) public view returns (bool) {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		user;
 		dummy;
@@ -471,14 +514,21 @@
 
 	/// Get collection owner.
 	///
-	/// @return Tuble with sponsor address and his substrate mirror.
+	/// @return Tuple with sponsor address and his substrate mirror.
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
+<<<<<<< HEAD
 	function collectionOwner() public view returns (Tuple6 memory) {
 		require(false, stub_error);
 		dummy;
 		return Tuple6(0x0000000000000000000000000000000000000000, 0);
+=======
+	function collectionOwner() public view returns (EthCrossAccount memory) {
+		require(false, stub_error);
+		dummy;
+		return EthCrossAccount(0x0000000000000000000000000000000000000000, 0);
+>>>>>>> misk: update stubs
 	}
 
 	/// Changes collection owner to another account
@@ -499,10 +549,17 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
+<<<<<<< HEAD
 	function collectionAdmins() public view returns (Tuple6[] memory) {
 		require(false, stub_error);
 		dummy;
 		return new Tuple6[](0);
+=======
+	function collectionAdmins() public view returns (EthCrossAccount[] memory) {
+		require(false, stub_error);
+		dummy;
+		return new EthCrossAccount[](0);
+>>>>>>> misk: update stubs
 	}
 
 	/// Changes collection owner to another account
@@ -510,16 +567,34 @@
 	/// @dev Owner can be changed only by current owner
 	/// @param newOwner new owner cross account
 	/// @dev EVM selector for this function is: 0xe5c9913f,
+<<<<<<< HEAD
 	///  or in textual repr: setOwnerCross((address,uint256))
 	function setOwnerCross(Tuple6 memory newOwner) public {
+=======
+	///  or in textual repr: setOwnerCross(EthCrossAccount)
+	///  or in the expanded repr: setOwnerCross((address,uint256))
+	function setOwnerCross(EthCrossAccount memory newOwner) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		newOwner;
 		dummy = 0;
 	}
 }
 
+/// @dev Cross account struct
+struct EthCrossAccount {
+	address eth;
+	uint256 sub;
+}
+
+/// @dev anonymous struct
+struct Tuple23 {
+	address field_0;
+	uint256 field_1;
+}
+
 /// @dev anonymous struct
-struct Tuple19 {
+struct Tuple20 {
 	string field_0;
 	bytes field_1;
 }
@@ -708,10 +783,16 @@
 	/// @param to The new owner
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
+<<<<<<< HEAD
 		Tuple6 memory from,
 		Tuple6 memory to,
+=======
+		EthCrossAccount memory from,
+		EthCrossAccount memory to,
+>>>>>>> misk: update stubs
 		uint256 tokenId
 	) public {
 		require(false, stub_error);
@@ -745,8 +826,14 @@
 	/// @param from The current owner of the RFT
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
+<<<<<<< HEAD
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
 	function burnFromCross(Tuple6 memory from, uint256 tokenId) public {
+=======
+	///  or in textual repr: burnFromCross(EthCrossAccount,uint256)
+	///  or in the expanded repr: burnFromCross((address,uint256),uint256)
+	function burnFromCross(EthCrossAccount memory from, uint256 tokenId) public {
+>>>>>>> misk: update stubs
 		require(false, stub_error);
 		from;
 		tokenId;
@@ -762,6 +849,7 @@
 		return 0;
 	}
 
+<<<<<<< HEAD
 	// /// @notice Function to mint multiple tokens.
 	// /// @dev `tokenIds` should be an array of consecutive numbers and first number
 	// ///  should be obtained with `nextTokenId` method
@@ -791,6 +879,37 @@
 	// 	dummy = 0;
 	// 	return false;
 	// }
+=======
+	/// @notice Function to mint multiple tokens.
+	/// @dev `tokenIds` should be an array of consecutive numbers and first number
+	///  should be obtained with `nextTokenId` method
+	/// @param to The new owner
+	/// @param tokenIds IDs of the minted RFTs
+	/// @dev EVM selector for this function is: 0x44a9945e,
+	///  or in textual repr: mintBulk(address,uint256[])
+	function mintBulk(address to, uint256[] memory tokenIds) public returns (bool) {
+		require(false, stub_error);
+		to;
+		tokenIds;
+		dummy = 0;
+		return false;
+	}
+
+	/// @notice Function to mint multiple tokens with the given tokenUris.
+	/// @dev `tokenIds` is array of pairs of token ID and token URI. Token IDs should be consecutive
+	///  numbers and first number should be obtained with `nextTokenId` method
+	/// @param to The new owner
+	/// @param tokens array of pairs of token ID and token URI for minted tokens
+	/// @dev EVM selector for this function is: 0x36543006,
+	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
+	function mintBulkWithTokenURI(address to, Tuple11[] memory tokens) public returns (bool) {
+		require(false, stub_error);
+		to;
+		tokens;
+		dummy = 0;
+		return false;
+	}
+>>>>>>> misk: update stubs
 
 	/// Returns EVM address for refungible token
 	///
@@ -806,17 +925,24 @@
 }
 
 /// @dev anonymous struct
+<<<<<<< HEAD
 struct Tuple8 {
+=======
+struct Tuple11 {
+>>>>>>> misk: update stubs
 	uint256 field_0;
 	string field_1;
 }
 
+<<<<<<< HEAD
 /// @dev anonymous struct
 struct Tuple6 {
 	address field_0;
 	uint256 field_1;
 }
 
+=======
+>>>>>>> misk: update stubs
 /// @title ERC-721 Non-Fungible Token Standard, optional enumeration extension
 /// @dev See https://eips.ethereum.org/EIPS/eip-721
 /// @dev the ERC-165 identifier for this interface is 0x780e9d63
@@ -708,10 +783,16 @@
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0xd5cf430b,
-	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
+	///  or in textual repr: transferFromCross(EthCrossAccount,EthCrossAccount,uint256)
+	///  or in the expanded repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
modifiedtests/src/eth/api/UniqueNFT.soldiffbeforeafterboth